#!/usr/bin/env node

const path = require('path');
const microset = require('../index.js');

let config;
try {
  config = require(path.resolve(process.cwd(), process.argv[2]));
} catch (err) {
  console.error('Unable to load config file. ' + err);
  process.exit(-1);
}

let services = new microset.ServiceRegistry();
if(config.logger && config.logger.level) {
  services.logger.level = config.logger.level;
}

for(let serviceDef of config.services) {
  let serviceConfig = serviceDef.config || {};
  services.register(serviceDef.from, serviceConfig);
}

for(let builderDef of config.builders) {
  let builder = microset.build[builderDef.name];
  if(!builder) {
    console.error(`Unknown builder '${builderDef.name}'`);
    process.exit(-2);
  }
  let builderConfig = builderDef.config || {};
  builder(services, builderConfig)
}
