const ProcessRpcBridge = require('./ProcessRpcBridge.js');
const Service = require('../Service.js');

(async function() {
  const bridge = new ProcessRpcBridge();
  await bridge.attachToProcess(process, 'stdin', 'stdout');
  console.debug = (...args) => bridge.call('logDebug', args);
  console.log = (...args) => bridge.call('logDebug', args);
  console.info = (...args) => bridge.call('logInfo', args);
  console.warn = (...args) => bridge.call('logWarn', args);
  console.error = (...args) => bridge.call('logError', args);
  console.exception = (...args) => bridge.call('logError', args);
  await bridge.call('logInfo', [`Service process started. PID: ${process.pid}`]);
  const servicePath = process.argv[2];
  await bridge.call('logDebug', [`Loading service class from '${servicePath}'`]);
  const ServiceDef = require(servicePath);
  if (!ServiceDef.prototype.constructor.name) {
    await bridge.call('logFatal', ['Service defintion cannot be anonymous class!']);
    process.exit(-1);
  }
  if (!(ServiceDef.prototype instanceof Service)) {
    await bridge.call('logFatal', ['Service defintion must extends Service class!']);
    process.exit(-1);
  }
  await bridge.call('logDebug', [`Service class loaded: '${ServiceDef.prototype.constructor.name}'. Creating an instance of service...`]);
  const service = new ServiceDef(bridge);
  await bridge.attachToTarget(service);
  await bridge.call('logDebug', [`Service instance created`]);
  service.id = await bridge.call('getServiceId');
  service.name = await bridge.call('getServiceName');
  await bridge.call('onProcessCreated');
})();
