/* istanbul ignore next */
/**
 * Mock of Process bridge
 * @private
 */
class ProcessRpcBridgeMock {
  /**
   * @constructor
   * @param {Object} mock - mock configuration
   */
  constructor(mock) {
    this._mock = mock;
  }

  /**
   * mocks Process bridge calls (mapping them to mock object)
   * @param {String} methodName - name of method to be called
   * @param {Array} params - list of parameters to be passed to the method
   */
  async call(methodName, params) {
    if (methodName === 'callService' && this._mock[params[0]] !== undefined && this._mock[params[0]][params[1]] !== undefined) {
      return this._mock[params[0]][params[1]](...params[2]);
    } else if (this._mock[methodName] !== undefined) {
      return this._mock[methodName](...params);
    }
  }
}
/* istanbul ignore next */
module.exports = function(ServiceDef, mockConfig) {
  mockConfig = mockConfig || {};
  const mock = {
    getServiceId: () => {
      return Math.round(Math.random()*0xffffffff).toString(16);
    },
    getServiceName: () => {
      return ServiceDef.prototype.constructor.name;
    },
    logDebug: () => {},
    logInfo: () => {},
    logWarn: () => {},
    logError: () => {},
    logFatal: () => {},
  };
  const fields = Object.keys(mockConfig);
  for (const i of fields) {
    mock[i] = mockConfig[i];
  }
  const bridge = new ProcessRpcBridgeMock(mock);
  const instance = new ServiceDef(bridge);

  instance.mock = mock;
  instance.id = instance.mock.getServiceId();
  instance.name = instance.mock.getServiceName();

  return instance;
};
